pub struct AtomicStorage(/* private fields */);Expand description
Thread-safe atomic storage implementation.
Uses atomic operations for concurrent access to token bucket state. Suitable for multi-threaded scenarios where multiple threads need to access the same token bucket.
Examples
use gardal::{TokenBucket, Limit, AtomicStorage, StdClock};
use std::num::NonZeroU32;
let limit = Limit::per_second(NonZeroU32::new(100).unwrap());
let bucket = TokenBucket::<AtomicStorage, _>::new(limit, StdClock);Trait Implementations
Sourceimpl Debug for AtomicStorage
impl Debug for AtomicStorage
Sourceimpl TimeStorage for AtomicStorage
impl TimeStorage for AtomicStorage